@@ -23,7 +23,7 @@ NUM_EPISODES = cartpole_sweep.NUM_EPISODES
 _settings = []
 for scale in [0.001, 0.03, 1.0, 30., 1000.]:
   for seed in range(4):
-    _settings.append({'reward_scale': scale, 'seed': seed})
+    _settings.append({'reward_scale': scale, 'seed': None})
 
 SETTINGS = tuple(_settings)
 TAGS = ('scale', 'generalization')
