@@ -18,5 +18,5 @@
 
 NUM_EPISODES = 1000
 
-SETTINGS = tuple({'seed': n} for n in range(20))
+SETTINGS = tuple({'mapping_seed': n} for n in range(20))
 TAGS = ('credit_assignment',)
